@@ -107,8 +107,7 @@ sub addMySQLParams()
 		$comm .= " --socket=\"$inputs{socket}\"";
 	}
 	if( $inputs{"ssl-options"} ){
-		if( $_[0] ne $MYSQLHOTCOPY &&  $inputs{"copy-plugin"} && 
-			    $_[0] eq $inputs{"copy-plugin"}) {  
+		if( $_[0] ne $MYSQLHOTCOPY ) {  
 			$comm .= " ".$inputs{"ssl-options"};
 		}
 	}
@@ -120,35 +119,16 @@ sub addMySQLParams()
 #$_[1] full string
 sub extractValue()
 {
-        if( $_[1] =~ /\n\|*\s+$_[0]\s+\|*\s+(\S+)\s+\|*\n/ ){
-		if( $1 ne "|" ){
-                	return $1;
-		}
+        if( $_[1] =~ /\n\|*\s+$_[0]\s+\|([^\|]+)\|*\n/ ){
+                if( $1 ne "|" ){
+                        my $x = $1;
+                        $x=~ s/^\s+//;
+                        $x=~ s/\s+$//;
+                        return $x;
+                }
         }
 }
 
-
-sub extractValue1()
-{
-	my $tmp;
-	my $data;
-	if( !$_[1] ){
-		return;
-	}
-	my @data1 = split( $_[0], $_[1] );
-	if( !defined $data1[1] || ! $data1[1] ) {
-		return;
-	}
-	shift @data1;
-	$data = join( $_[0], @data1 );
-	my @xx = split( /\|/, $data );
-	$data = $xx[1];
-	chomp( $data );
-	$data=~ s/^\s+//;
-	$data=~ s/\s+$//;
-	return $data;
-}
-
 #Shuts down mysql using "mysqladmin shutdown" command
 sub shutdownMySQL() 
 {
@@ -397,6 +377,9 @@ sub checkForCompressEncryptPlugin()
 		}else{
 			$inputs{$name} = "";
 		}
+		if( $inputs{"backup-type"} eq "quick" ){
+			&printLog( "since backup-type is quick, the $name option will be ignored\n" );
+		}
 	}else{
 		delete $inputs{$name};
 	}
@@ -432,6 +415,30 @@ sub checkBackupWhat()
 
 sub checkForSnapshot()
 {
+	if( ! defined $inputs{"backup-type"} ){
+		$inputs{"backup-type"} = "regular";
+	}
+	if( $inputs{"backup-type"} ne "regular" && $inputs{"backup-type"} ne "quick" ){
+		&printAndDie( "Specified backup-type not correct. Please specify either 'regular' or 'quick'.\n" );
+	}
+	if( $inputs{"backup-level"} == 1 ){
+		$inputs{"backup-type"} = "regular";
+	}
+
+	if( $inputs{"backup-mode"} eq "logical" ){
+		$inputs{"backup-type"} = "regular";
+	    	&printLog( "The quick backup-type is supported only for snapshot backups. Setting backup-type to 'regular'\n" );
+	}
+	if( $inputs{"backup-type"} eq "quick" ){
+		if( defined $inputs{"copy-plugin"} ){
+			my $name = basename( $inputs{"copy-plugin"} );
+			if( $name eq "windows-copy.pl"){
+				$inputs{"backup-type"} = "regular";
+	    			&printLog( "The quick backup-type is not supported on windows. Setting backup-type to 'regular'\n" );
+			}
+		}
+		$inputs{"synchronous-checksum"} = -1;
+	}
 	if( ! defined $inputs{"snapshot-plugin"} ){
 		if( defined $inputs{"lvm-snapshot"} || $inputs{"snapshot-size"} ){
 			$inputs{"snapshot-plugin"} = "/usr/share/mysql-zrm/plugins/lvm-snapshot.pl";
@@ -439,11 +446,16 @@ sub checkForSnapshot()
 				&printLog( "Using ".$inputs{"snapshot-plugin"}." as the default plugin since snapshot-plugin has not been specified\n" );
 			}
 		}else{
+			if( $inputs{"backup-type"} ne "regular" ){
+	    			&printLog( "No snapshot-plugin specified. The quick backup-type is supported only for snapshot backups. Setting backup-type to 'regular'\n" );
+				$inputs{"backup-type"} = "regular";
+			}
 			return;
 		}
 	}
 	if( $inputs{"snapshot-plugin"} =~ /^\s*$/ ){
 		delete $inputs{"snapshot-plugin"};
+		$inputs{"backup-type"} = "regular";
 		return;
 	}
 
@@ -460,6 +472,7 @@ sub checkForSnapshot()
 	if( ! defined $inputs{"snapshot-size" } ){
 		$inputs{"snapshot-size" } = 10;
 	}
+
 }
 
 #verifys if all of the inputs are ok.
